@@ -143,9 +143,7 @@ def inet_aton(text: Union[str, bytes], ignore_scope: bool = False) -> bytes:
     if m is not None:
         b = dns.ipv4.inet_aton(m.group(2))
         btext = (
-            "{}:{:02x}{:02x}:{:02x}{:02x}".format(
-                m.group(1).decode(), b[0], b[1], b[2], b[3]
-            )
+            f"{m.group(1).decode()}:{b[0]:02x}{b[1]:02x}:{b[2]:02x}{b[3]:02x}"
         ).encode()
     #
     # Try to turn '::<whatever>' into ':<whatever>'; if no match try to
